@@ -2,8 +2,14 @@ from asyncio import get_event_loop
 
 from rfxcom.transport import AsyncioTransport
 
+from home.config import PACKET_HANDLERS
+from home.collect.handlers import load_handlers
 
-def collect(dev_name, callbacks):
+
+def collect(dev_name, callbacks=None):
+
+    if callbacks is None:
+        callbacks = dict(load_handlers(PACKET_HANDLERS))
 
     loop = get_event_loop()
 
